Crate ais_keystore_lib

Crate ais_keystore_lib 

High level client helpers for interacting with the keystore server.

This library wraps the gRPC API exposed by the ais_keystore binary and provides convenience functions for performing common actions. All functions are asynchronous and return errors using the dusa_collection_utils crate types.

Modules

encryption
grpc
key_store
shared

Functions

conn_test
Basic connectivity test for the gRPC client.
generate_key
Generates a new key with a defined length via the gRPC API. The result is the raw key bytes.
get_key
Retrieve a key and return only the raw value.
get_key_data
Retrieve a key and return its data structure using gRPC.
migrate_key
Migrate a key via gRPC.
store_key
Store a key using the gRPC API.