pub struct ConnectionStream {
pub addy: Option<String>,
pub protocol: Proto,
pub tcp_stream: Option<Box<TcpStream>>,
pub unix_stream: Option<Box<UnixStream>>,
}Expand description
Represents an open connection to the keystore.
Fields
addy: Option<String>protocol: Prototcp_stream: Option<Box<TcpStream>>unix_stream: Option<Box<UnixStream>>Implementations
Sourceimpl ConnectionStream
impl ConnectionStream
Sourcepub async fn new_tcp_connection(addy: String) -> Result<Self, ErrorArrayItem>
pub async fn new_tcp_connection(addy: String) -> Result<Self, ErrorArrayItem>
Create a new TCP connection to the keystore server.
Sourcepub async fn new_unix_connection() -> Result<Self, ErrorArrayItem>
pub async fn new_unix_connection() -> Result<Self, ErrorArrayItem>
Create a new Unix domain socket connection to the keystore server.
Sourcepub async fn ensure_connection(&mut self) -> Result<Self, ErrorArrayItem>
pub async fn ensure_connection(&mut self) -> Result<Self, ErrorArrayItem>
Ensure the internal connection is alive, reconnecting if necessary.
Sourcepub fn get_stream_mut(&mut self) -> StreamMut<'_>
pub fn get_stream_mut(&mut self) -> StreamMut<'_>
Obtain a mutable reference to the underlying stream regardless of the protocol.
Sourcepub fn get_protocol(&self) -> Proto
pub fn get_protocol(&self) -> Proto
Return the protocol associated with this connection.